#[non_exhaustive]pub enum PaymentStatus {
Accepted,
PartiallyAccepted,
CompletedDebtor,
CompletedCreditor,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Accepted
The payment was received and is getting processed.
Especially without realtime bookings this is often the final status reported by the ASPSP.
PartiallyAccepted
The payment was partially accepted, i.e. only some of the transactions of a bulk payment or the payment needs further authorization.
CompletedDebtor
Settlement on the debtor’s account has been completed.
CompletedCreditor
Settlement on the creditor’s account has been completed.