pub enum SecrecyLevel {
Plain,
Otp,
Password,
}Expand description
Level of secrecy for an input field.
Variants
Plain
The data is not a secret.
Otp
The data is a one-time password. This can usually be treated as no secret but the implementer might still choose to mask the input.
Password
The data is a secret password. Input must be masked.