#[non_exhaustive]pub enum ServiceBlockedCode {
MissingSetup,
ActionRequired,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingSetup
Something is not set up for the user, e.g., there are no TAN methods.
ActionRequired
User attention is required via another channel. Typically the user needs to log into the Online Banking.