#[non_exhaustive]pub enum UnsupportedProductReason {
Limit,
Recipient,
Scheduled,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Limit
The amount is not allowed for the payment product.
Recipient
The recipient is not capable to receive the payment product.
Scheduled
Scheduled payments are not supported.