pub struct Authenticated<T> { /* private fields */ }Expand description
Data authenticated with an HMAC
Use to_data() to access the data locally.
Serialization is supported for transfer to a remote system as JSON Web Token.
The remote system can verify and read the data from the data claim:
use jsonwebtoken::{decode, DecodingKey, Validation, Algorithm};
use serde::Deserialize;
#[derive(Deserialize, Clone, Debug)]
struct Claims {
data: T,
exp: u64,
}
let data = decode::<Claims>(
&jwt,
&DecodingKey::from_secret(hmac_key),
&Validation::new(Algorithm::HS256),
)?.claims.data;Implementations
Sourceimpl<T> Authenticated<T>where
T: Serialize,
impl<T> Authenticated<T>where
T: Serialize,
Sourceimpl<T> Authenticated<T>where
T: for<'de> Deserialize<'de> + Clone,
impl<T> Authenticated<T>where
T: for<'de> Deserialize<'de> + Clone,