Redirect

Struct Redirect 

pub struct Redirect<S> {
    pub url: Url,
    pub context: ConfirmationContext<S>,
}
User redirect.

The user is meant to get sent to the url and the context can be used for continuing the process at the service that issued the redirect object afterward.

A web application needs to direct the user agent to the returned URL. A desktop or mobile application could either open it in a browser or inside an element like a WebView.

Fields

url: Urlcontext: ConfirmationContext<S>