#[non_exhaustive]pub struct BatchData {
pub number_of_transactions: Option<u32>,
pub transactions: Vec<BatchTransactionDetails>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.number_of_transactions: Option<u32>Number of transactions in the batch, if known.
transactions: Vec<BatchTransactionDetails>Details of transactions in the batch.
Note that this does not necessarily match a given number of transactions. It could be e.g. empty as no details are given or a single entry with common details on all transactions in the batch.