#[non_exhaustive]pub struct ExchangeRate {
pub source_currency: String,
pub target_currency: Option<String>,
pub unit_currency: Option<String>,
pub exchange_rate: Decimal,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_currency: StringISO 4217 Alpha 3 currency code of the source currency that gets converted.
target_currency: Option<String>ISO 4217 Alpha 3 currency code of the target currency that the source currency gets converted into.
unit_currency: Option<String>ISO 4217 Alpha 3 currency code of the unit currency for the exchange rate.
exchange_rate: DecimalTrait Implementations
Sourceimpl Clone for ExchangeRate
impl Clone for ExchangeRate
Sourcefn clone(&self) -> ExchangeRate
fn clone(&self) -> ExchangeRate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExchangeRate
impl Debug for ExchangeRate
Sourceimpl<'de> Deserialize<'de> for ExchangeRate
impl<'de> Deserialize<'de> for ExchangeRate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ExchangeRate
impl PartialEq for ExchangeRate
Sourcefn eq(&self, other: &ExchangeRate) -> bool
fn eq(&self, other: &ExchangeRate) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExchangeRate
impl Serialize for ExchangeRate
impl Eq for ExchangeRate
impl StructuralPartialEq for ExchangeRate