pub struct Redirect<S> {
pub url: Url,
pub context: ConfirmationContext<S>,
}Expand description
User redirect.
The user is meant to get sent to the url and the context can
be used for continuing the process at the service that issued the redirect object afterward.
A web application needs to direct the user agent to the returned URL. A desktop or mobile application could either open it in a browser or inside an element like a WebView.
Fields
url: Urlcontext: ConfirmationContext<S>Trait Implementations
Sourceimpl<'de, S> Deserialize<'de> for Redirect<S>where
S:,
impl<'de, S> Deserialize<'de> for Redirect<S>where
S:,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<S> Eq for Redirect<S>