#[non_exhaustive]pub struct Transaction {Show 23 fields
pub entry_reference: Option<String>,
pub batch: Option<BatchData>,
pub booking_date: Option<NaiveDate>,
pub value_date: Option<NaiveDate>,
pub transaction_date: Option<NaiveDate>,
pub status: TransactionStatus,
pub account_servicer_reference: Option<String>,
pub payment_id: Option<String>,
pub transaction_id: Option<String>,
pub end_to_end_id: Option<String>,
pub mandate_id: Option<String>,
pub creditor_id: Option<String>,
pub amount: Amount,
pub reversal: bool,
pub original_amount: Option<Amount>,
pub exchanges: Vec<ExchangeRate>,
pub fees: Vec<Fee>,
pub creditor: Option<Party>,
pub debtor: Option<Party>,
pub remittance_information: Vec<String>,
pub purpose_code: Option<String>,
pub bank_transaction_codes: Vec<BankTransactionCode>,
pub additional_information: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entry_reference: Option<String>Identifier used for delta requests.
batch: Option<BatchData>booking_date: Option<NaiveDate>Booking date (ASPSP’s books).
value_date: Option<NaiveDate>Value date. Expected / requested value date in case of pending entries.
transaction_date: Option<NaiveDate>Date of the actual transaction, e.g. a card payment.
status: TransactionStatusTransaction status.
account_servicer_reference: Option<String>Unique reference assigned by the account servicer.
payment_id: Option<String>Unique identifier assigned by the sending party.
transaction_id: Option<String>Unique identifier assigned by the first instructing agent.
end_to_end_id: Option<String>Unique end-to-end identifier assigned by the initiating party.
mandate_id: Option<String>Mandate identifier.
creditor_id: Option<String>SEPA creditor identifier.
amount: AmountTransaction amount as billed to the account.
reversal: boolIndicator for reversals.
original_amount: Option<Amount>Original amount of the transaction.
exchanges: Vec<ExchangeRate>Exchange rates.
fees: Vec<Fee>Any fees related to the transaction.
creditor: Option<Party>Creditor data. In case of reversals this refers to the initial transaction.
debtor: Option<Party>Debtor data. In case of reversals this refers to the initial transaction.
remittance_information: Vec<String>Remittance (purpose).
purpose_code: Option<String>ISO 20022 ExternalPurpose1Code.
bank_transaction_codes: Vec<BankTransactionCode>Bank Transaction Codes.
additional_information: Option<String>Additional information attached to the transaction.
This might be a proprietary, localized, human-readable long text corresponding to some machine-readable bank transaction code that is not directly provided by the bank.